@@ -1,6 +1,6 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
@@ -34,6 +34,16 @@ void AccountsAwareObject::accountRemoved(Account account)
 	Q_UNUSED(account)
 }
 
+void AccountsAwareObject::accountRegistered(Account account)
+{
+	Q_UNUSED(account)
+}
+
+void AccountsAwareObject::accountUnregistered(Account account)
+{
+	Q_UNUSED(account)
+}
+
 void AccountsAwareObject::notifyAccountAdded(Account account)
 {
 	foreach (AccountsAwareObject *object, Objects)
