@@ -22,7 +22,7 @@
  */
 
 #include "contacts/contact.h"
-#include "misc/path-conversion.h"
+#include "misc/kadu-paths.h"
 
 #include "avatar.h"
 
@@ -80,4 +80,5 @@ KaduSharedBase_PropertyBoolReadDef(Avatar, Empty, true)
 KaduSharedBase_PropertyDefCRW(Avatar, QDateTime, lastUpdated, LastUpdated, QDateTime())
 KaduSharedBase_PropertyDefCRW(Avatar, QDateTime, nextUpdate, NextUpdate, QDateTime())
 KaduSharedBase_PropertyDefCRW(Avatar, QPixmap, pixmap, Pixmap, QPixmap())
+KaduSharedBase_PropertyReadDef(Avatar, QString, smallFilePath, SmallFilePath, QString())
 KaduSharedBase_PropertyDefCRW(Avatar, QString, filePath, FilePath, QString())
